==> mx-bootrepair_23.9.tar.xz: BUILD/translations/mx-boot-repair_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparador do Arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>O MX Reparador do Arranque é um utilitário que pode ser usado para reinstalar o carregador do arranque GRUB na ESP (EFI Sistema Partition), no MBR (Master Boot Record) do disco ou no PBR (Partition Boot Record) da partição raiz ( / , root), para reconstruir o ficheiro de configuração do GRUB, para fazer cópias de segurança do MBR ou do PBR, ou para restaurar o MBR ou o PBR.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>O que fazer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstalar o carregador do arranque GRUB em ESP, MBR ou PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Refazer o ficheiro de configuração do GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar MBR ou PBR a partir de cópia (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Select Boot Method</source>
        <translation>Dados para instalação do Arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Raíz (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>root</source>
        <translation>PBR (da partição raíz)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Install on:</source>
        <translation>Instalar em:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>Select root location:</source>
        <translation>Seleccionar a localização da raiz ( / , root):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Partição de Sistema EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>O GRUB está a ser instalado em %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <location filename="../mainwindow.cpp" line="229"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="450"/>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="598"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <location filename="../mainwindow.cpp" line="613"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Não foi possível definir o ambiente chroot.
Verificar novamente a localização seleccionada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>O ficheiro de configuração do GRUB (grub.cfg) está a ser refeito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>A guardar o MBR/PBR de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>You are going to write the content of </source>
        <translation>Vai ser escrito o conteúdo de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source> to </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>

Are you sure?</source>
        <translation>
    
Seguramente?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>A restaurar o MBR/PBR em %1 a partir da cópia.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Não foi encontrada qualquer ESP (EFI System Partition). Criar uma partição ESP e voltar a tentar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Select %1 location:</source>
        <translation>Seleccionar a localização de %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Back</source>
        <translation>Voltar atrás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>O processo terminou com êxito.&lt;p&gt;&lt;b&gt;Sair do MX Reparador do Arranque?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>O processo terminou. Ocorreram erros.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Introduzir a senha para desbloquear a partição encriptada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Não foi possível abrir o contentor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Select GRUB location</source>
        <translation>Seleccionar a localização do GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>Select Item to Back Up</source>
        <translation>Seleccionar o item a Copiar para Segurança</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Select Item to Restore</source>
        <translation>Seleccionar o item a Restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>No location was selected.</source>
        <translation>Nenhum local foi escolhido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Por favor, selecione a partição root do sistema que deseja reparar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Select backup file name</source>
        <translation>Escolher o nome da cópia de segurança.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="606"/>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>No file was selected.</source>
        <translation>Não foi seleccionado qualquer ficheiro.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Seleccionar cópia de segurança do MBR ou do PBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simples de reparação do arranque para o MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Não foi possível montar a partição %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>Could not create a temporary folder</source>
        <translation>Não foi possível criar uma pasta temporária</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>MX Boot Repair</source>
        <translation>MX-Reparador do Arranque</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_25.4.01.tar.xz: BUILD/translations/mx-boot-repair_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparador do Arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>O MX Reparador do Arranque é um utilitário que pode ser usado para reinstalar o carregador do arranque GRUB na ESP (EFI Sistema Partition), no MBR (Master Boot Record) do disco ou no PBR (Partition Boot Record) da partição raiz ( / , root), para reconstruir o ficheiro de configuração do GRUB, para fazer cópias de segurança do MBR ou do PBR, ou para restaurar o MBR ou o PBR.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>O que fazer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Reinstalar o carregador do arranque GRUB em ESP, MBR ou PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Refazer o ficheiro de configuração do GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar MBR ou PBR a partir de cópia (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Select Boot Method</source>
        <translation>Dados para instalação do Arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>Partição de Sistema EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Raíz (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.cpp" line="594"/>
        <source>root</source>
        <translation>PBR (da partição raíz)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Select root location:</source>
        <translation>Seleccionar a localização da raiz ( / , root):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Install on:</source>
        <translation>Instalar em:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>O GRUB está a ser instalado em %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="216"/>
        <location filename="../mainwindow.cpp" line="271"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <location filename="../mainwindow.cpp" line="481"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="632"/>
        <location filename="../mainwindow.cpp" line="636"/>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="649"/>
        <location filename="../mainwindow.cpp" line="657"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <location filename="../mainwindow.cpp" line="217"/>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Não foi possível definir o ambiente chroot.
Verificar novamente a localização seleccionada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>O ficheiro de configuração do GRUB (grub.cfg) está a ser refeito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>Generating initramfs images on: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>A guardar o MBR/PBR de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>You are going to write the content of </source>
        <translation>Vai ser escrito o conteúdo de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source> to </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>

Are you sure?</source>
        <translation>
    
Seguramente?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>A restaurar o MBR/PBR em %1 a partir da cópia.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Não foi encontrada qualquer ESP (EFI System Partition). Criar uma partição ESP e voltar a tentar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Select %1 location:</source>
        <translation>Seleccionar a localização de %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Back</source>
        <translation>Voltar atrás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>O processo terminou com êxito.&lt;p&gt;&lt;b&gt;Sair do MX Reparador do Arranque?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>O processo terminou. Ocorreram erros.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Introduzir a senha para desbloquear a partição encriptada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Não foi possível abrir o contentor LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Select GRUB location</source>
        <translation>Seleccionar a localização do GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Select initramfs options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="617"/>
        <source>Select Item to Back Up</source>
        <translation>Seleccionar o item a Copiar para Segurança</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Select Item to Restore</source>
        <translation>Seleccionar o item a Restaurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>No location was selected.</source>
        <translation>Nenhum local foi escolhido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Por favor, selecione a partição root do sistema que deseja reparar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <source>Select backup file name</source>
        <translation>Escolher o nome da cópia de segurança.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>No file was selected.</source>
        <translation>Não foi seleccionado qualquer ficheiro.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Seleccionar cópia de segurança do MBR ou do PBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simples de reparação do arranque para o MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="685"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="716"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Não foi possível montar a partição %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>Could not create a temporary folder</source>
        <translation>Não foi possível criar uma pasta temporária</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>MX Boot Repair</source>
        <translation>MX-Reparador do Arranque</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>You must run this program with admin access.</source>
        <translation>Deve executar este programa como administrador.</translation>
    </message>
</context>
</TS>
